@@ -267,19 +267,16 @@ def ET(root,screen,logfile,logfilename,
         else:
             thisHOMO,NBasis,NGroups,groupname,groupatoms,contrib,evalue=readorbital_data(inputfile)
             inputfile.close()             
-            if len(thisHOMO)==2 or len(logfile.homos)==2:
-                screen.write("Not going to use orbital_data.txt as this is an unrestricted "
-                             "calculation, and this feature is not yet supported.")
-            else:
-                orbdata=True        
-                screen.write("Using orbital_data.txt\n")            
-                if thisHOMO!=logfile.homos:
-                    screen.write("Disagreement on HOMO...orbital_data.txt says "+str(thisHOMO)+"\n"+logfile.filename+" says "+str(logfile.homos)+"\n")
-                    return False
-                screenCD=[]
-                for i in range(len(logfile.etenergies)): # For each transition
-                    screenCD.append("")
-                    # charge density [before, after] for each of the groups for each of the transitions
+
+            orbdata=True        
+            screen.write("Using orbital_data.txt\n")
+            if thisHOMO != list(logfile.homos):
+                screen.write("Disagreement on HOMO...orbital_data.txt says "+str(thisHOMO)+"\n"+logfile.filename+" says "+str(logfile.homos)+"\n")
+                return False
+            screenCD=[]
+            for i in range(len(logfile.etenergies)): # For each transition
+                screenCD.append("")
+                # charge density [before, after] for each of the groups for each of the transitions
 
         majorCIS, minorCIS = [[] for x in logfile.etenergies], [[] for x in logfile.etenergies]
         allpercent = [[] for x in logfile.etenergies]
@@ -293,11 +290,9 @@ def ET(root,screen,logfile,logfilename,
                 totcontribs += mycontrib # tot up the contribs
                 percontrib = int(mycontrib * 100 + .5)
                 if orbdata:
-                    for k in range(NGroups):    
-                        CD[k][0] = (CD[k][0] + mycontrib *
-                                    contrib[0, thisCIS[0][0], k])
-                        CD[k][1] = (CD[k][1] + mycontrib *
-                                    contrib[0, thisCIS[1][0], k])
+                    for k in range(NGroups):
+                        CD[k][0] += mycontrib * contrib[thisCIS[0][1], thisCIS[0][0], k] # Add to 'before' charge density
+                        CD[k][1] += mycontrib * contrib[thisCIS[1][1], thisCIS[1][0], k] # Add to 'after' charge density
                 alphabeta = ["", ""]
                 if unres:
                     alphabeta = [["(A)", "(B)"][thisCIS[0][1]], ["(A)", "(B)"][thisCIS[1][1]]]
