@@ -156,7 +156,13 @@ class App:    # This sets up the GUI
             frame5.pack(side=TOP)
             frame6=Frame(self.frame4)
             frame6.pack(side=TOP)
-
+            frame7=Frame(self.frame4)
+            frame7.pack(side=TOP)
+            frame8=Frame(self.frame4)
+            frame8.pack(side=TOP)
+            frame9=Frame(self.frame4)
+            frame9.pack(side=TOP)
+			
             Label(frame5,text="Start:").pack(side=LEFT)
             self.start=Entry(frame5,width=5)
             self.start.pack(side=LEFT)
@@ -173,7 +179,7 @@ class App:    # This sets up the GUI
             self.FWHM=Entry(frame5,width=3)
             self.FWHM.pack(side=LEFT)
             self.FWHM.insert(0,self.settings['ir_raman.fwhm'])
-
+			
             Label(frame6,text="Scaling factors:").pack(side=LEFT)
             self.scale=StringVar()
             r=Radiobutton(frame6,text="General",variable=self.scale,value="Gen")
@@ -184,6 +190,20 @@ class App:    # This sets up the GUI
             r2=Radiobutton(frame6,text="Individual",variable=self.scale,value="Indiv")
             r2.pack(side=LEFT)
             r.select()
+
+            Label(frame7, text="The following are used to calculate Raman intensities:").pack()
+
+            Label(frame8, text="Exc. wavelength (nm)").pack(side=LEFT)
+            self.excitation = Entry(frame8, width=6)
+            self.excitation.pack(side=LEFT)
+            self.excitation.insert(0, self.settings['ir_raman.excitation'])
+            Label(frame8, text="Temp. (K)").pack(side=LEFT)
+            self.temperature = Entry(frame8,width=6)
+            self.temperature.pack(side=LEFT)
+            self.temperature.insert(0, self.settings['ir_raman.temperature'])
+            if not hasattr(self.data, "vibramans"):
+                self.excitation.configure(state=DISABLED)
+                self.temperature.configure(state=DISABLED)
             
         elif s=="FIND":
             frame6=Frame(self.frame4)
@@ -286,16 +306,6 @@ class App:    # This sets up the GUI
                 self.eddmbtn.configure(state=DISABLED)
 
 
-##	elif s=="EDDM":
-##            Label(self.frame4,text="Transitions:").pack(side=LEFT)
-##            self.trans=Entry(self.frame4,width=10)
-##            self.trans.pack(side=LEFT)
-##            self.trans.insert(0,"1-3,7,9")
-##
-##        elif s=="NMR":
-##            self.createnmrpanel(self.frame4)
-
-
     def createnmrpanel(self,parent):
 # Sets up the Panel for the NMR options
         frame6=Frame(parent)
@@ -355,7 +365,6 @@ class App:    # This sets up the GUI
             self.nmrrb2a.configure(state=NORMAL)
             self.nmrrb2b.configure(state=NORMAL)
 
-
     def UVupdate(self):
 # What to do when the user chooses UVVis or CD for UVVis.py
         if self.UVplot.get()==False:
@@ -394,7 +403,7 @@ class App:    # This sets up the GUI
                     self.data = self.logfile.parse()
                 worked = GeoOpt(self.root,self.screen,self.data,int(self.numpts.get()),self.settings['global settings.gnuplot'])                
             elif s=="IR_RAMAN":
-                worked = Vibfreq(self.root,self.screen,self.data,self.logfile.filename,int(self.start.get()),int(self.end.get()),int(self.numpts.get()),float(self.FWHM.get()),self.scale.get(),float(self.scalefactor.get()),self.settings['global settings.gnuplot'])
+                worked = Vibfreq(self.root,self.screen,self.data,self.logfile.filename,int(self.start.get()),int(self.end.get()),int(self.numpts.get()),float(self.FWHM.get()),self.scale.get(),float(self.scalefactor.get()),float(self.excitation.get()),float(self.temperature.get()),self.settings['global settings.gnuplot'])
             elif s=="FIND":
                 if self.searchrad.get()=="Custom":
                     worked = Search(self.screen,self.logfile.filename,self.customsearch.get(),self.casesensitive.get())
@@ -560,24 +569,15 @@ class App:    # This sets up the GUI
         writeoutconfigfile(self.settings,settingsfile)
 
     def readprefs(self):
+        # The default settings are overwritten by any existing stored
+        # settings.
 
-        settingsfile = self.getsettingsfile()
-        self.settings={}
+        defaultgnuplot = os.path.join(installlocation,"gnuplot460","bin","wgnuplot.exe")
+        if not sys.platform == "win32":
+            defaultgnuplot = os.path.join(os.sep, "usr", "bin", "gnuplot")
 
-        if os.path.isfile(settingsfile): # Check for settings file
-            # Found it! - so read it in.
-            self.settings=readinconfigfile(settingsfile)
-            
-        else: # Initialise the settings file (and directory)
-            settingsdir = os.path.dirname(settingsfile)
-            if not os.path.isdir(settingsdir):
-                os.mkdir(settingsdir)
-            defaultgnuplot = os.path.join(installlocation,"gnuplot400","bin","wgnuplot.exe")
-            if not sys.platform == "win32":
-                defaultgnuplot = os.path.join(os.sep, "usr", "bin", "gnuplot")
-
-            self.settings={
-                           'global settings.gnuplot' : defaultgnuplot,
+        self.settings = {
+                           'global settings.gnuplot': defaultgnuplot,
                            'find.text1':'SCF Done',
                            'find.text2':'k 501%k502',
                            'find.text3':'imaginary',
@@ -585,7 +585,9 @@ class App:    # This sets up the GUI
                            'ir_raman.start':'0',
                            'ir_raman.end':'4000',
                            'ir_raman.numpoints':'500',
-                           'ir_raman.fwhm':'3',
+                           'ir_raman.fwhm':'10',
+                           'ir_raman.excitation':'785',
+                           'ir_raman.temperature':'293.15',
                            'mo.start':'-20',
                            'mo.end':'0',
                            'mo.fwhm':'0.3',
@@ -594,13 +596,19 @@ class App:    # This sets up the GUI
                            'uvvis.numpoints':'500',
                            'uvvis.fwhm':'3000',
                            'uvvis.sigma':'0.2',
-##                               'eddm.cubman':'C:\\Gaussian\\cubman.exe',
-##                               'eddm.formchk':'C:\\Gaussian\\formchk.exe',
-##                               'eddm.cubegen':'C:\\Gaussian\\cubegen.exe',
-##                               'nmr.data':os.path.join(settingsdir,"nmrdata.txt")
                            }
-            self.saveprefs() # Save the inital settings file
 
+        settingsfile = self.getsettingsfile()
+        if os.path.isfile(settingsfile): # Check for settings file
+            # Found it! - so read it in.
+            self.settings.update(readinconfigfile(settingsfile))
+            
+        else: # Initialise the settings file (and directory)
+            settingsdir = os.path.dirname(settingsfile)
+            if not os.path.isdir(settingsdir):
+                os.mkdir(settingsdir)
+
+            self.saveprefs() # Save the inital settings file
  
     def webdocs(self):
         webbrowser.open(os.path.join(installlocation,"..","Docs","index.html"))
