@@ -25,14 +25,14 @@ import tkMessageBox     # For the Error Dialog
 from tempfile import mkstemp
 
 from Tkinter import *
-import Image as PIL # Python Imaging Library
-import ImageTk      # Python Imaging Library
+from PIL import Image # Python Imaging Library
+from PIL import ImageTk      # Python Imaging Library
 from gnupy import Gnuplot
 
 # Kludge necessary for using PIL when using py2exe
 # (see http://www.py2exe.org/index.cgi/PIL_and_py2exe)
-import PngImagePlugin # Python Imaging Library
-PIL._initialized = 2
+from PIL import PngImagePlugin # Python Imaging Library
+Image._initialized = 2
 
 class DisplayPlot(object):
     def __init__(self,root,g,title):
@@ -66,7 +66,7 @@ class DisplayPlot(object):
         frame2.pack(side=TOP)
 
         try:
-            image = PIL.open(self.filename)
+            image = Image.open(self.filename)
             self.graph = ImageTk.PhotoImage(image)
             
             self.item2 = self.canvas2.create_image(7,7,anchor=NW,image=self.graph)
