@@ -240,64 +240,64 @@ def Popanalysis(root,screen,logfile,logfilename,start,end,COOP,FWHM,makeorigin,g
             outputfile.write(line)
         outputfile.close()
 
+        if root:
 
-
-        # Gnuplot the DOS spectrum as follows
-        #
-        # For res:
-        #  one plot with stacked PDOS plus evalues at bottom
-        # For unres:
-        #  one plot with stacked sum_of_PDOS's plus both evalues at bottom
-        
-        g = Gnuplot(gnuplotexec)
-        
-        if groups and pop:
-            screen.write("Plotting the stacked PDOS\n")
-            if not unres:
-                total = numpy.zeros(len(spectrum.xvalues),'d')
-                for i in range(len(groups.groups)):
-                    total += spectrum.spectrum[i,:]
-                    g.data(zip(spectrum.xvalues,total),
-                           "title '%s' with lines" % groups.groups.keys()[i])
-            else:
-                total = numpy.zeros(len(spectrum.xvalues),'d')
-                for i in range(len(groups.groups)):
-                    total += spectrum.spectrum[i,:] + spectrum_beta.spectrum[i,:]
-                    g.data(zip(spectrum.xvalues,total),
-                           "title '%s' with lines" % groups.groups.keys()[i])
-        else:
-            screen.write("Plotting the total DOS\n")
-            if not unres:
-                g.data(zip(spectrum.xvalues, spectrum.spectrum[0,:]),
-                       "title 'DOS spectrum' with lines")
-            else:
-                g.data(zip(spectrum.xvalues, spectrum.spectrum[0,:]),
-                       "title 'Alpha DOS spectrum' with lines")
-                g.data(zip(spectrum_beta.xvalues, spectrum_beta.spectrum[0,:]),
-                       "title 'Beta DOS spectrum' with lines")
-                g.data(zip(spectrum.xvalues,
-                          (spectrum.spectrum[0,:]+spectrum_beta.spectrum[0,:])*0.5),
-                       "title 'Total DOS spectrum (scaled by 0.5)' with lines")
-           
-        # Plot the evalues
-        g.data([ (x,-1) for x in evalue[0][:HOMO[0]+1] ],
-               "title '%sOccupied Orbitals' with impulses" % (["","Alpha "][unres]))
-        g.data([ (x,-1) for x in evalue[0][HOMO[0]+1:] ],
-               "title '%sVirtual Orbitals' with impulses" % (["","Alpha "][unres]))
-        if unres: # For the extra beta impulses
-            g.data([ (x,-1) for x in evalue[1][:HOMO[0]+1] ],
-                   "title 'Beta Occupied Orbitals' with impulses")
-            g.data([ (x,-1) for x in evalue[1][HOMO[0]+1:] ],
-                   "title 'Beta Virtual Orbitals' with impulses")
+            # Gnuplot the DOS spectrum as follows
+            #
+            # For res:
+            #  one plot with stacked PDOS plus evalues at bottom
+            # For unres:
+            #  one plot with stacked sum_of_PDOS's plus both evalues at bottom
             
-        g.commands("set xrange [%s:%s]" % (start,end),
-                   "set yrange [-1:*]",
-                   "set xlabel 'Energy (eV)'")
+            g = Gnuplot(gnuplotexec)
+            
+            if groups and pop:
+                screen.write("Plotting the stacked PDOS\n")
+                if not unres:
+                    total = numpy.zeros(len(spectrum.xvalues),'d')
+                    for i in range(len(groups.groups)):
+                        total += spectrum.spectrum[i,:]
+                        g.data(zip(spectrum.xvalues,total),
+                               "title '%s' with lines" % groups.groups.keys()[i])
+                else:
+                    total = numpy.zeros(len(spectrum.xvalues),'d')
+                    for i in range(len(groups.groups)):
+                        total += spectrum.spectrum[i,:] + spectrum_beta.spectrum[i,:]
+                        g.data(zip(spectrum.xvalues,total),
+                               "title '%s' with lines" % groups.groups.keys()[i])
+            else:
+                screen.write("Plotting the total DOS\n")
+                if not unres:
+                    g.data(zip(spectrum.xvalues, spectrum.spectrum[0,:]),
+                           "title 'DOS spectrum' with lines")
+                else:
+                    g.data(zip(spectrum.xvalues, spectrum.spectrum[0,:]),
+                           "title 'Alpha DOS spectrum' with lines")
+                    g.data(zip(spectrum_beta.xvalues, spectrum_beta.spectrum[0,:]),
+                           "title 'Beta DOS spectrum' with lines")
+                    g.data(zip(spectrum.xvalues,
+                              (spectrum.spectrum[0,:]+spectrum_beta.spectrum[0,:])*0.5),
+                           "title 'Total DOS spectrum (scaled by 0.5)' with lines")
+               
+            # Plot the evalues
+            g.data([ (x,-1) for x in evalue[0][:HOMO[0]+1] ],
+                   "title '%sOccupied Orbitals' with impulses" % (["","Alpha "][unres]))
+            g.data([ (x,-1) for x in evalue[0][HOMO[0]+1:] ],
+                   "title '%sVirtual Orbitals' with impulses" % (["","Alpha "][unres]))
+            if unres: # For the extra beta impulses
+                g.data([ (x,-1) for x in evalue[1][:HOMO[0]+1] ],
+                       "title 'Beta Occupied Orbitals' with impulses")
+                g.data([ (x,-1) for x in evalue[1][HOMO[0]+1:] ],
+                       "title 'Beta Virtual Orbitals' with impulses")
+                
+            g.commands("set xrange [%s:%s]" % (start,end),
+                       "set yrange [-1:*]",
+                       "set xlabel 'Energy (eV)'")
 
-        if not unres:
-            DisplayPlot(root,g,"DOS spectrum")
-        else:
-            DisplayPlot(root,g,"DOS spectrum (sum of alpha plus beta electrons)")
+            if not unres:
+                DisplayPlot(root,g,"DOS spectrum")
+            else:
+                DisplayPlot(root,g,"DOS spectrum (sum of alpha plus beta electrons)")
 
         return # End of densityofstates()
                 
