@@ -21,7 +21,6 @@ import traceback
 import copy             # For deepcopy...until I find a better way of doing this
 import ConfigParser     # For writing the settings to an .ini file
 
-from gausssum.cclib.parser import ADF, GAMESS, Gaussian
 from gausssum.plot import DisplayPlot
 from gausssum.gnupy import Gnuplot
 
@@ -37,9 +36,6 @@ class PreferencesPopupBox(tkSimpleDialog.Dialog):
         self.transient(parent)
         self.settings=settings                    # Note that changes to self.settings will affect the global self.settings thru 'settings'
         self.oldsettings=settings.copy()          # Remember the current settings
-##        self.filetype=StringVar()
-##        self.filetype.set(self.settings['global settings.filetype'])
-
         if title:
             self.title(title)
 
@@ -72,45 +68,29 @@ class PreferencesPopupBox(tkSimpleDialog.Dialog):
         self.frame2.pack()
         Label(self.frame1,text="").pack()
         
-        Label(self.frame1,text="Find.py").pack()
+        Label(self.frame1,text="Search file").pack()
         self.frame3=Frame(self.frame1)
         self.frame3.pack()
         Label(self.frame1,text="").pack()
         
-        Label(self.frame1,text="IR_Raman.py").pack()
+        Label(self.frame1,text="Frequencies").pack()
         self.frame4=Frame(self.frame1)
         self.frame4.pack()
         Label(self.frame1,text="").pack()
         
-        Label(self.frame1,text="MO.py").pack()
+        Label(self.frame1,text="Orbitals").pack()
         self.frame5=Frame(self.frame1)
         self.frame5.pack()
         Label(self.frame1,text="").pack()
         
-        Label(self.frame1,text="UVVis.py").pack()
+        Label(self.frame1,text="Electronic transitions").pack()
         self.frame6=Frame(self.frame1)
         self.frame6.pack()
         Label(self.frame1,text="").pack()
 
-##        Label(self.frame1,text="EDDM.py").pack()
-##        self.frame8=Frame(self.frame1)
-##        self.frame8.pack()
-##        Label(self.frame1,text="").pack()
-##        
-##        Label(self.frame1,text="NMR.py").pack()
-##        self.frame7=Frame(self.frame1)
-##        self.frame7.pack()
-
         # The Global Settings section
         self.frame2a=Frame(self.frame2)
         self.frame2a.pack()
-##        Label(self.frame2a,text="File type:").pack(side=LEFT)
-##        self.b0=Radiobutton(self.frame2a, text="Gaussian", variable=self.filetype, value="Gaussian", command=self.update)
-##        self.b0.pack(side=LEFT)
-##        self.b2=Radiobutton(self.frame2a, text="GAMESS", variable=self.filetype, value="GAMESS", command=self.update)
-##        self.b2.pack(side=LEFT)
-##        self.b1=Radiobutton(self.frame2a, text="Hyperchem", variable=self.filetype, value="Hyperchem", command=self.update)
-##        self.b1.pack(side=LEFT)
         self.frame2b=Frame(self.frame2)
         self.frame2b.pack()
         Label(self.frame2b,text="Gnuplot:").grid(row=0,column=0)
@@ -119,8 +99,6 @@ class PreferencesPopupBox(tkSimpleDialog.Dialog):
         self.gnuplot.delete(0,END)
         self.gnuplot.insert(0,self.settings['global settings.gnuplot'])
         Button(self.frame2b,text="Test",command=self.testgnuplot).grid(row=0,column=2,padx=5)
-
-        
         
         # The Find.py section
         Label(self.frame3,text="Search for:").grid(row=0,column=0)
@@ -138,24 +116,37 @@ class PreferencesPopupBox(tkSimpleDialog.Dialog):
             self.find[i].insert(0,self.settings[ 'find.text%d'%(i+1) ])
 
         # The IR_Raman.py section
-        self.irraman=[None]*4
-        Label(self.frame4,text="Start:").grid(row=0,column=0)
-        self.irraman[0]=Entry(self.frame4,width=5)
+        self.frame4a = Frame(self.frame4)
+        self.frame4a.pack()
+        self.irraman=[None]*6
+        Label(self.frame4a,text="Start:").grid(row=0,column=0)
+        self.irraman[0]=Entry(self.frame4a,width=5)
         self.irraman[0].grid(row=0,column=1)
-        Label(self.frame4,text="End:").grid(row=0,column=2)        
-        self.irraman[1]=Entry(self.frame4,width=5)
+        Label(self.frame4a,text="End:").grid(row=0,column=2)        
+        self.irraman[1]=Entry(self.frame4a,width=5)
         self.irraman[1].grid(row=0,column=3)
-        Label(self.frame4,text="Num pts:").grid(row=0,column=4)                
-        self.irraman[2]=Entry(self.frame4,width=5)
+        Label(self.frame4a,text="Num pts:").grid(row=0,column=4)                
+        self.irraman[2]=Entry(self.frame4a,width=5)
         self.irraman[2].grid(row=0,column=5)
-        Label(self.frame4,text="FWHM:").grid(row=0,column=6)                
-        self.irraman[3]=Entry(self.frame4,width=5)
+        Label(self.frame4a,text="FWHM:").grid(row=0,column=6)                
+        self.irraman[3]=Entry(self.frame4a,width=5)
         self.irraman[3].grid(row=0,column=7)
-        a=['start','end','numpoints','fwhm']
-        for i in range(4):
+
+        self.frame4b = Frame(self.frame4)
+        self.frame4b.pack()
+    
+        Label(self.frame4b,text="Exc. wavelength:").grid(row=0,column=0)
+        self.irraman[4]=Entry(self.frame4b,width=5)
+        self.irraman[4].grid(row=0,column=1)
+        Label(self.frame4b,text="Temp:").grid(row=0,column=2)
+        self.irraman[5]=Entry(self.frame4b,width=6)
+        self.irraman[5].grid(row=0,column=3)
+        a=['start','end','numpoints','fwhm','excitation','temperature']
+        for i in range(6):
             self.irraman[i].delete(0,END)
             self.irraman[i].insert(0,self.settings[ 'ir_raman.%s'%a[i] ])
 
+
         # The MO.py section
         self.mo=[None]*3
         Label(self.frame5,text="Start:").grid(row=0,column=0)
@@ -196,39 +187,10 @@ class PreferencesPopupBox(tkSimpleDialog.Dialog):
             self.uvvis[i].delete(0,END)
             self.uvvis[i].insert(0,self.settings['uvvis.%s'%(a[i])])
 
-##        # The EDDM.py section
-##        Label(self.frame8,text="Path to cubman:").grid(row=0,column=0)
-##        self.cubman=Entry(self.frame8,width=35)
-##        self.cubman.grid(row=0,column=1)
-##        self.cubman.delete(0,END)
-##        self.cubman.insert(0,self.settings['eddm.cubman'])
-##        Button(self.frame8,text="Check",command=self.checkcubman).grid(row=0,column=2,padx=5)
-##        Label(self.frame8,text="Path to formchk:").grid(row=1,column=0)
-##        self.formchk=Entry(self.frame8,width=35)
-##        self.formchk.grid(row=1,column=1)
-##        self.formchk.delete(0,END)
-##        self.formchk.insert(0,self.settings['eddm.formchk'])
-##        Button(self.frame8,text="Check",command=self.checkformchk).grid(row=1,column=2,padx=5)
-##        Label(self.frame8,text="Path to cubegen:").grid(row=2,column=0)
-##        self.cubegen=Entry(self.frame8,width=35)
-##        self.cubegen.grid(row=2,column=1)
-##        self.cubegen.delete(0,END)
-##        self.cubegen.insert(0,self.settings['eddm.cubegen'])
-##        Button(self.frame8,text="Check",command=self.checkcubegen).grid(row=2,column=2,padx=5)
-##
-##
-##        # The NMR.py section
-##        Label(self.frame7,text="NMR reference info:").grid(row=0,column=0)
-##        self.nmrdata=Entry(self.frame7,width=30)
-##        self.nmrdata.grid(row=0,column=1)
-##        self.nmrdata.delete(0,END)
-##        self.nmrdata.insert(0,self.settings['nmr.data'])
-##	Label(self.frame7,text="").grid(row=1)
-
         x=(652-450)/2+self.parent.winfo_rootx()
         y=(480-410)/2+self.parent.winfo_rooty()
         
-        self.geometry("450x410+"+str(x)+"+"+str(y)) # Place it in the centre of the root window
+        self.geometry("450x460+"+str(x)+"+"+str(y)) # Place it in the centre of the root window
 
     def buttonbox(self): # Override
         box = Frame(self)
@@ -304,16 +266,13 @@ For example (in Windows): C:\\Program Files\\Gnuplot\\bin\\Wgnuplot.exe'''
         # Remembers the settings
         # If they are different from before, they will be saved by 'preferences()'
 
-##        self.settings['global settings.filetype']=self.filetype.get()
-        self.settings['global settings.gnuplot']=self.gnuplot.get()
-##        self.settings['eddm.cubman']=self.cubman.get()
-##        self.settings['eddm.formchk']=self.formchk.get()
-##        self.settings['eddm.cubegen']=self.cubegen.get()        
-##        self.settings['nmr.data']=self.nmrdata.get()    
+        self.settings['global settings.gnuplot']=self.gnuplot.get()   
+        a=['start','end','numpoints','fwhm','excitation','temperature']
+        for i in range(6):
+            self.settings['ir_raman.%s'%(a[i])]=self.irraman[i].get()
         a=['start','end','numpoints','fwhm']
         for i in range(4):
             self.settings['find.text%d'%(i+1)]=self.find[i].get()
-            self.settings['ir_raman.%s'%(a[i])]=self.irraman[i].get()
             self.settings['uvvis.%s'%(a[i])]=self.uvvis[i].get()
         self.settings['uvvis.sigma']=self.uvvis[4].get()
         a=['start','end','fwhm']
