@@ -249,12 +249,11 @@ class Groups(object):
     atoms or a group of atoms.
 
     Usage:
-     Groups(aonames,atombasis=None,groups=None,type=None,file=None)
+     Groups(filename, atomnos, aonames, atombasis)
     where
+     atomnos is a list of the atomic numbers of the atoms
      aonames is a list of the 'names' of each atomic orbital
      atombasis is a list for each atom of the indices of the basis fns on that atom
-        (this is ignored for type="allorbitals" and required otherwise)
-     type is one of "allorbitals", "allatoms", "orbitals" or "atoms"
 
     Attributes:
      groups -- a dictionary of the partition of the orbitals among groups
@@ -288,8 +287,11 @@ class Groups(object):
         """
         inputfile = open(filename,"r")
         grouptype = inputfile.next().strip()
+        while not grouptype: # Ignore blank lines
+            grouptype = inputfile.next().strip()
         groups = {}
         for line in inputfile:
+            if not line.strip(): continue # Ignore blank lines
             groupname = line.strip()
             atoms = []
             line = inputfile.next()
